function[G] = get_givens(i,j,aij,r,arj)
%GET_GIVENS(i,j,aij,r,arj) Generates the specified Givens rotation matrix
% (i,j) is the position of entry we want to clear.
% We use row r to clear this entry.
% aij is the element at position (i,j)
% arj is the element at position (r,j)
% G (returned) is the specified Givens rotation matrix.

    G = givens(arj,aij);

    % From 'help givens':
    % ************************************************************
    %   G = GIVENS(x,y) returns the complex Givens rotation matrix
    %
    %       | c       s |                  | x |     | r |
    %   G = |           |   such that  G * |   |  =  |   |
    %       |-conj(s) c |                  | y |     | 0 |
    %
    %   where c is real, s is complex, and c^2 + |s|^2 = 1. 
    % ************************************************************
    %
    % G contains the 4 entries that differ from the identity matrix.
    % For x, y real this is just the usual Givens rotation matrix.
end